Coverage for C:\src\imod-python\imod\mf6\interfaces\ipackage.py: 76%

1 import abc

2 from abc import abstractmethod

3 from typing import Any

4

5 from imod.mf6.interfaces.ipackagebase import IPackageBase

6

7

8 class IPackage(IPackageBase, metaclass=abc.ABCMeta):

9 """

10 Interface for imod.mf6.package.Package

11 """

12

13 @abstractmethod

14 def _valid(self, value):

15 raise NotImplementedError

16

17 @abstractmethod

18 def __init__(self, *args, **kwargs) -> None:

19 raise NotImplementedError

20

21 @abc.abstractmethod

22 def get_non_grid_data(self, grid_names: list[str]) -> dict[str, Any]:

23 raise NotImplementedError

24

25 @property

26 @abc.abstractmethod

27 def auxiliary_data_fields(self) -> dict[str, str]:

28 raise NotImplementedError

29

30 @abstractmethod

31 def is_regridding_supported(self) -> bool:

32 raise NotImplementedError